@@ -1,5 +1,5 @@
 """Ideal Air Schema"""
-from pydantic import Field, validator, root_validator, constr
+from pydantic import Field, root_validator, constr
 from typing import Union
 from enum import Enum
 
@@ -21,16 +21,16 @@ class IdealAirSystemAbridged(IDdEnergyBaseModel):
     economizer_type: EconomizerType = Field(
         EconomizerType.differential_dry_bulb,
         description='Text to indicate the type of air-side economizer used on the '
-            'ideal air system. Economizers will mix in a greater amount of outdoor '
-            'air to cool the zone (rather than running the cooling system) when '
-            'the zone needs cooling and the outdoor air is cooler than the zone.'
+        'ideal air system. Economizers will mix in a greater amount of outdoor '
+        'air to cool the zone (rather than running the cooling system) when '
+        'the zone needs cooling and the outdoor air is cooler than the zone.'
     )
 
     demand_controlled_ventilation: bool = Field(
         False,
         description='Boolean to note whether demand controlled ventilation should '
-            'be used on the system, which will vary the amount of ventilation air '
-            'according to the occupancy schedule of the zone.'
+        'be used on the system, which will vary the amount of ventilation air '
+        'according to the occupancy schedule of the zone.'
     )
 
     sensible_heat_recovery: float = Field(
@@ -38,7 +38,7 @@ class IdealAirSystemAbridged(IDdEnergyBaseModel):
         ge=0,
         le=1,
         description='A number between 0 and 1 for the effectiveness of sensible '
-            'heat recovery within the system.'
+        'heat recovery within the system.'
     )
 
     latent_heat_recovery: float = Field(
@@ -46,7 +46,7 @@ class IdealAirSystemAbridged(IDdEnergyBaseModel):
         ge=0,
         le=1,
         description='A number between 0 and 1 for the effectiveness of latent '
-            'heat recovery within the system.'
+        'heat recovery within the system.'
     )
 
     heating_air_temperature: float = Field(
@@ -67,18 +67,18 @@ class IdealAirSystemAbridged(IDdEnergyBaseModel):
         Autosize(),
         ge=0,
         description='A number for the maximum heating capacity in Watts. This '
-            'can also be an Autosize object to indicate that the capacity should '
-            'be determined during the EnergyPlus sizing calculation. This can also '
-            'be a NoLimit boject to indicate no upper limit to the heating capacity.'
+        'can also be an Autosize object to indicate that the capacity should '
+        'be determined during the EnergyPlus sizing calculation. This can also '
+        'be a NoLimit object to indicate no upper limit to the heating capacity.'
     )
 
     cooling_limit: Union[Autosize, NoLimit, float] = Field(
         Autosize(),
         ge=0,
         description='A number for the maximum cooling capacity in Watts. This '
-            'can also be an Autosize object to indicate that the capacity should '
-            'be determined during the EnergyPlus sizing calculation. This can also '
-            'be a NoLimit boject to indicate no upper limit to the cooling capacity.'
+        'can also be an Autosize object to indicate that the capacity should '
+        'be determined during the EnergyPlus sizing calculation. This can also '
+        'be a NoLimit object to indicate no upper limit to the cooling capacity.'
     )
 
     heating_availability: str = Field(
@@ -86,7 +86,7 @@ class IdealAirSystemAbridged(IDdEnergyBaseModel):
         min_length=1,
         max_length=100,
         description='An optional identifier of a schedule to set the availability of '
-            'heating over the course of the simulation.'
+        'heating over the course of the simulation.'
     )
 
     cooling_availability: str = Field(
@@ -94,7 +94,7 @@ class IdealAirSystemAbridged(IDdEnergyBaseModel):
         min_length=1,
         max_length=100,
         description='An optional identifier of a schedule to set the availability of '
-            'cooling over the course of the simulation.'
+        'cooling over the course of the simulation.'
     )
 
     @root_validator
@@ -109,16 +109,18 @@ class IdealAirSystemAbridged(IDdEnergyBaseModel):
     class Config:
         @staticmethod
         def schema_extra(schema, model):
-            schema['properties']['heating_limit']['anyOf'] = [
+            schema['properties']['heating_limit']['anyOf'] = \
+                [
                     {"$ref": "#/components/schemas/NoLimit"},
                     {"$ref": "#/components/schemas/Autosize"},
                     {"type": "number", "minimum": 0}
-                ]
-            schema['properties']['cooling_limit']['anyOf'] = [
+            ]
+            schema['properties']['cooling_limit']['anyOf'] = \
+                [
                     {"$ref": "#/components/schemas/NoLimit"},
                     {"$ref": "#/components/schemas/Autosize"},
                     {"type": "number", "minimum": 0}
-                ]
+            ]
 
 
 if __name__ == '__main__':
