@@ -1,7 +1,6 @@
 """Model energy properties."""
 from pydantic import Field, constr
 from typing import List, Union
-from enum import Enum
 
 from .._base import NoExtraBaseModel
 from .constructionset import ConstructionSetAbridged, ConstructionSet
@@ -25,15 +24,15 @@ class ShadeEnergyPropertiesAbridged(NoExtraBaseModel):
     type: constr(regex='^ShadeEnergyPropertiesAbridged$') = \
         'ShadeEnergyPropertiesAbridged'
 
-    construction:  str = Field(
+    construction: str = Field(
         default=None,
         min_length=1,
         max_length=100,
         description='Identifier of a ShadeConstruction to set the reflectance and '
-            'specularity of the Shade. If None, the construction is set by the'
-            'parent Room construction_set, the Model global_construction_set or '
-            '(in the case fo an orphaned shade) the EnergyPlus default of 0.2 '
-            'diffuse reflectance.'
+        'specularity of the Shade. If None, the construction is set by the'
+        'parent Room construction_set, the Model global_construction_set or '
+        '(in the case fo an orphaned shade) the EnergyPlus default of 0.2 '
+        'diffuse reflectance.'
     )
 
     transmittance_schedule: str = Field(
@@ -41,8 +40,8 @@ class ShadeEnergyPropertiesAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier of a schedule to set the transmittance of the shade, '
-            'which can vary throughout the simulation. If None, the shade will '
-            'be completely opauqe.'
+        'which can vary throughout the simulation. If None, the shade will '
+        'be completely opaque.'
     )
 
 
@@ -56,10 +55,10 @@ class DoorEnergyPropertiesAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier of an OpaqueConstruction or WindowConstruction '
-            'for the door. Note that the host door must have the is_glass property '
-            'set to True to assign a WindowConstruction. If None, the construction '
-            'is set by the parent Room construction_set or the Model '
-            'global_construction_set.'
+        'for the door. Note that the host door must have the is_glass property '
+        'set to True to assign a WindowConstruction. If None, the construction '
+        'is set by the parent Room construction_set or the Model '
+        'global_construction_set.'
     )
 
 
@@ -73,8 +72,8 @@ class ApertureEnergyPropertiesAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier of a WindowConstruction for the aperture. If None, the '
-            'construction is set by the parent Room construction_set or the Model '
-            'global_construction_set.'
+        'construction is set by the parent Room construction_set or the Model '
+        'global_construction_set.'
     )
 
 
@@ -88,8 +87,8 @@ class FaceEnergyPropertiesAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier of an OpaqueConstruction for the Face. If None, the '
-            'construction is set by the parent Room construction_set or the '
-            'Model global_construction_set.'
+        'construction is set by the parent Room construction_set or the '
+        'Model global_construction_set.'
     )
 
 
@@ -103,8 +102,8 @@ class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier of a ConstructionSet to specify all default '
-            'constructions for the Faces, Apertures, and Doors of the Room. If '
-            'None, the Room will use the Model global_construction_set.'
+        'constructions for the Faces, Apertures, and Doors of the Room. If '
+        'None, the Room will use the Model global_construction_set.'
     )
 
     program_type: str = Field(
@@ -112,7 +111,7 @@ class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier of a ProgramType to specify all default schedules '
-            'and loads for the Room. If None, the Room will have no loads or setpoints.'
+        'and loads for the Room. If None, the Room will have no loads or setpoints.'
     )
 
     hvac: str = Field(
@@ -120,15 +119,15 @@ class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='An optional identifier of a HVAC system (such as an IdealAirSystem)'
-            ' that specifies how the Room is conditioned. If None, it will be assumed '
-            'that the Room is not conditioned.'
+        ' that specifies how the Room is conditioned. If None, it will be assumed '
+        'that the Room is not conditioned.'
     )
 
     people: PeopleAbridged = Field(
         default=None,
         description='People object to describe the occupancy of the Room.'
     )
-    
+
     lighting: LightingAbridged = Field(
         default=None,
         description='Lighting object to describe the lighting usage of the Room.'
@@ -170,8 +169,8 @@ class ModelEnergyProperties(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for the ConstructionSet to be used for all '
-            'objects lacking their own construction or a parent Room construction_set. '
-            'This ConstructionSet must appear under the Model construction_sets.'
+        'objects lacking their own construction or a parent Room construction_set. '
+        'This ConstructionSet must appear under the Model construction_sets.'
     )
 
     construction_sets: List[Union[ConstructionSetAbridged, ConstructionSet]] = Field(
@@ -185,8 +184,8 @@ class ModelEnergyProperties(NoExtraBaseModel):
         OpaqueConstruction, WindowConstruction, AirBoundaryConstruction]] = Field(
         default=None,
         description='A list of all unique constructions in the model. This includes '
-            'constructions across all Faces, Apertures, Doors, Shades, Room '
-            'ConstructionSets, and the global_construction_set.'
+        'constructions across all Faces, Apertures, Doors, Shades, Room '
+        'ConstructionSets, and the global_construction_set.'
     )
 
     materials: List[Union[EnergyMaterial, EnergyMaterialNoMass, EnergyWindowMaterialGas,
@@ -196,7 +195,7 @@ class ModelEnergyProperties(NoExtraBaseModel):
                           EnergyWindowMaterialShade]] = Field(
         default=None,
         description='A list of all unique materials in the model. This includes '
-            'materials needed to make the Model constructions.'
+        'materials needed to make the Model constructions.'
     )
 
     hvacs: List[Union[IdealAirSystemAbridged]] = Field(
@@ -213,11 +212,11 @@ class ModelEnergyProperties(NoExtraBaseModel):
                           ScheduleRuleset, ScheduleFixedInterval]] = Field(
         default=None,
         description='A list of all unique schedules in the model. This includes '
-            'schedules across all HVAC systems, ProgramTypes, Rooms, and Shades.'
+        'schedules across all HVAC systems, ProgramTypes, Rooms, and Shades.'
     )
 
     schedule_type_limits: List[ScheduleTypeLimit] = Field(
         default=None,
         description='A list of all unique ScheduleTypeLimits in the model. This '
-            'all ScheduleTypeLimits needed to make the Model schedules.'
+        'all ScheduleTypeLimits needed to make the Model schedules.'
     )
